@@ -21,13 +21,13 @@ from pathlib import Path
 
 from jupyter_server.utils import url_path_join
 
-from .dependency_management import DependenciesFilesHandler, PipenvHandler
-from .dependency_management import ThothConfigHandler, ThothAdviseHandler
+from .dependency_management import DependenciesFilesHandler, PipenvHandler, PythonVersionHandler
+from .dependency_management import ThothConfigHandler, ThothAdviseHandler, ThothInvectioHandler
 from .dependency_management import JupyterKernelHandler, DependencyInstalledHandler, DependencyInstallHandler
 
 HERE = Path(__file__).parent.resolve()
 
-__version__ = "0.4.1"
+__version__ = "0.6.4"
 
 with (HERE / "labextension" / "package.json").open() as fid:
     data = json.load(fid)
@@ -72,9 +72,11 @@ def _load_jupyter_server_extension(lab_app):
     custom_handlers = [
         (url_path_join(base_url, f"/{url_path}/thoth/config"), ThothConfigHandler),
         (url_path_join(base_url, f"/{url_path}/thoth/resolution"), ThothAdviseHandler),
+        (url_path_join(base_url, f"/{url_path}/thoth/invectio"), ThothInvectioHandler),
         (url_path_join(base_url, f"/{url_path}/pipenv"), PipenvHandler),
         (url_path_join(base_url, f"/{url_path}/kernel/packages"), DependencyInstalledHandler),
         (url_path_join(base_url, f"/{url_path}/kernel/install"), DependencyInstallHandler),
+        (url_path_join(base_url, f"/{url_path}/kernel/python"), PythonVersionHandler),
         (url_path_join(base_url, f"/{url_path}/kernel/create"), JupyterKernelHandler),
         (url_path_join(base_url, f"/{url_path}/file/dependencies"), DependenciesFilesHandler),
     ]
