@@ -17,12 +17,14 @@
 """Dependency Management APIs for jupyter server."""
 
 from .dependencies_files_handler import DependenciesFilesHandler
-from .dependencies_discover_handler import DependencyInstalledHandler
+from .discover_handler import DependencyInstalledHandler
+from .discover_handler import PythonVersionHandler
 from .kernel_handler import JupyterKernelHandler
 from .install_handler import DependencyInstallHandler
 from .pipenv import PipenvHandler
 from .thoth import ThothAdviseHandler
 from .thoth_config_handler import ThothConfigHandler
+from .thoth_invectio import ThothInvectioHandler
 
 __all__ = [
     "DependenciesFilesHandler",
@@ -30,6 +32,8 @@ __all__ = [
     "DependencyInstalledHandler",
     "JupyterKernelHandler",
     "PipenvHandler",
+    "PythonVersionHandler",
     "ThothAdviseHandler",
     "ThothConfigHandler",
+    "ThothInvectioHandler"
 ]
