@@ -14,6 +14,7 @@ import {
   JupyterFrontEndPlugin
 } from '@jupyterlab/application';
 
+
 // Customizations
 import { ManageDependenciesButtonExtension } from './dependencyManagementButton';
 
@@ -27,7 +28,8 @@ import { ManageDependenciesButtonExtension } from './dependencyManagementButton'
 /**
  * Initialization data for the jupyterlab_requirements extension.
  */
-const extension: JupyterFrontEndPlugin<void> = {
+
+const extension: JupyterFrontEndPlugin<string> = {
   id: 'jupyterlab_requirements',
   autoStart: true,
   activate
@@ -39,16 +41,21 @@ const extension: JupyterFrontEndPlugin<void> = {
  * @param app Jupyter Front End
  */
 
-function activate (
+async function activate (
   app: JupyterFrontEnd,
-): void {
+): Promise<string> {
 
   // Add button in notebook menu
-  console.log('jupyterlab-requirements extension is activated!');
-  // ManageDependenciesButtonExtension initialization code
-  const buttonExtension = new ManageDependenciesButtonExtension();
-  app.docRegistry.addWidgetExtension('Notebook', buttonExtension);
+  try {
+    // ManageDependenciesButtonExtension initialization code
+    const buttonExtension = new ManageDependenciesButtonExtension();
+    app.docRegistry.addWidgetExtension('Notebook', buttonExtension);
+    console.log('jupyterlab-requirements extension is activated!');
+  } catch (reason) {
+    console.error('Error on setting the jupyterlab-requirements extension');
+  }
 
+  return "ready"
 }
 
 export default extension;
