@@ -9,21 +9,23 @@
  * @since  0.0.1
  */
 
-
 import { requestAPI, THOTH_JUPYTER_INTEGRATION_API_BASE_NAME } from './handler';
+import * as utils from "./utils";
 
 /**
  * Function: Install dependencies in the new kernel.
  */
 
 export async function install_packages (
-  kernel_name?: string,
+  kernel_name: string,
+  resolution_engine: string,
   init: RequestInit = {},
 ): Promise<string> {
 
   // POST request
   const dataToSend = {
-    kernel_name: kernel_name
+    kernel_name: kernel_name,
+    resolution_engine: resolution_engine
   };
 
   const endpoint: string = 'kernel/install'
@@ -66,6 +68,26 @@ export async function discover_installed_packages (
   }
 }
 
+/**
+ * Function: Discover Python version.
+ */
+
+ export async function discover_python_version (
+  init: RequestInit = {},
+): Promise<string> {
+
+  const endpoint: string = '/kernel/python'
+
+  try {
+    const packages = await requestAPI<any>(endpoint, {
+      method: 'GET'
+    });
+    return JSON.parse(JSON.stringify(packages));
+  } catch (reason) {
+    console.error('Error on GET /' + THOTH_JUPYTER_INTEGRATION_API_BASE_NAME + '/' + endpoint + ':', reason);
+  }
+}
+
 /**
  * Function: Create new kernel.
  */
@@ -127,3 +149,32 @@ export async function store_dependencies (
       console.error('Error on POST /' + THOTH_JUPYTER_INTEGRATION_API_BASE_NAME + '/' + endpoint + ':', reason);
     }
   }
+
+
+/**
+ * Function: Gather library usage from notebook cells.
+ */
+
+export async function gather_library_usage(
+  notebook_content: string,
+  init: RequestInit = {},
+): Promise<Array<string>> {
+
+  // POST request
+  const dataToSend = {
+    notebook_content: utils.escape( notebook_content ),
+  };
+
+  const endpoint: string = 'thoth/invectio'
+
+  try {
+    const gathered_packages = await requestAPI<any>(endpoint, {
+      body: JSON.stringify(dataToSend),
+      method: 'POST'
+    });
+    return JSON.parse(JSON.stringify(gathered_packages));
+  } catch (reason) {
+    console.error('Error on POST /' + THOTH_JUPYTER_INTEGRATION_API_BASE_NAME + '/' + endpoint + ':', reason);
+  }
+
+}
