@@ -10,7 +10,7 @@
  */
 
 import { requestAPI, THOTH_JUPYTER_INTEGRATION_API_BASE_NAME } from './handler';
-import { Advise, PipenvResult, ThothConfig, RuntimeEnvornment } from './types/thoth';
+import { Advise, PipenvResult, ThothConfig, RuntimeEnvironment } from './types/thoth';
 
 export async function retrieve_config_file (
   kernel_name: string,
@@ -36,7 +36,7 @@ export async function retrieve_config_file (
 }
 
 export async function update_thoth_config_on_disk (
-  runtime_environment: RuntimeEnvornment,
+  runtime_environment: RuntimeEnvironment,
   force: boolean,
   init: RequestInit = {}
 ): Promise<string> {
@@ -62,6 +62,8 @@ export async function update_thoth_config_on_disk (
 
 export async function lock_requirements_with_thoth (
   kernel_name: string,
+  thoth_timeout: number,
+  notebook_content: string,
   thoth_config: string,
   requirements: string,
   init: RequestInit = {},
@@ -70,6 +72,8 @@ export async function lock_requirements_with_thoth (
   // POST request
   const dataToSend = {
     kernel_name: kernel_name,
+    thoth_timeout: thoth_timeout,
+    notebook_content: notebook_content,
     thoth_config: thoth_config,
     requirements: requirements
   };
